==> centreon-web-24.04.25.tar.gz: centreon-web-24.04.25/www/front_src/src/Dashboards/SingleInstancePage/Dashboard/translatedLabels.ts <==
export const labelSave = 'Save';
export const labelEditDashboard = 'Edit dashboard';
export const labelAddWidget = 'Add widget';
export const labelEditWidget = 'Edit widget';
export const labelAddAWidget = 'Add a widget';
export const labelCancel = 'Cancel';
export const labelExitDashboard = 'Exit {{dashboardName}}';
export const labelExitEditionMode = 'Exit edition mode';
export const labelLeaveEditionModeChangesNotSaved =
  'If you leave the edition mode, your changes will not be saved.';
export const labelQuitDashboardChangesNotSaved =
  'If you leave {{dashboardName}}, your changes will not be saved.';
export const labelYourDashboardHasBeenSaved = 'Your dashboard has been saved';
export const labelSelectAWidgetType = 'Select a widget type';
export const labelSearch = 'Search';
export const labelNoWidgetFound = 'No widget found';
export const labelDeleteAWidget = 'Delete widget';
export const labelWidgetType = 'Widget type';
export const labelPleaseChooseAWidgetToActivatePreview =
  'Select a widget type to activate the preview.';
export const labelDeleteWidget = 'Delete widget';
export const labelTheWidgetWillBeDeletedWithName =
  'The {{name}} widget will be permanently deleted.';
export const labelTheWidgetWillBeDeleted =
  'The widget will be permanently deleted.';
export const labelTitle = 'Title';
export const labelDescription = 'Description';
export const labelWidgetProperties = 'Widget properties';
export const labelCommonProperties = 'Common properties';
export const labelRequired = 'Required';
export const labelMoreActions = 'More actions';
export const labelDatasetSelection = 'Dataset selection';
export const labelResources = 'Resources';
export const labelHostGroup = 'Host Group';
export const labelHostCategory = 'Host Category';
export const labelServiceGroup = 'Service Group';
export const labelServiceCategory = 'Service Category';
export const labelHost = 'Host';
export const labelService = 'Service';
export const labelDelete = 'Delete';
export const labelResourceType = 'Resource type';
export const labelSelectAResource = 'Select resource';
export const labelSelectResourceType = 'Select type';
export const labelMetrics = 'Metrics';
export const labelPleaseSelectAResource = 'Please select a resource';
export const labelYouHaveTooManyMetrics =
  'You have too many metrics, please filter more resources to optimize platform performance.';
export const labelServiceName = 'Service name';
export const labelMetric = 'Metric';
export const labelSelectMetric = 'Select metric';
export const labelPleaseSelectAMetric = 'Please select a metric';
export const labelYouCanSelectUpToTwoMetricUnits =
  'You can select a maximum of 2 metric units.';
export const labelShowDescription = 'Show description';
export const labelAddFilter = 'Add filter';
export const labelAddMetric = 'Add metric';
export const labelAvailable = 'available';
export const labelYourWidgetHasBeenModified =
  'Your widget has been modified successfully!';
export const labelYourWidgetHasBeenCreated =
  'Your widget has been created successfully!';
export const labelValueSettings = 'Value settings';
export const labelRefreshInterval = 'Refresh interval';
export const labelDashboardGlobalInterval = 'Dashboard global interval';
export const labelCustomRefreshInterval = 'Custom refresh interval';
export const labelSecond = 'second';
export const labelManualRefresh = 'Manual refresh';
export const labelInterval = 'Interval';
export const labelThresholds = 'Thresholds';
export const labelShowThresholds = 'Show thresholds';
export const labelWarningThreshold = 'Warning threshold';
export const labelCriticalThreshold = 'Critical threshold';
export const labelDefault = 'Default';
export const labelCustom = 'Custom';
export const labelThresholdsAreAutomaticallyHidden =
  'Thresholds are automatically hidden as soon as you select 2 metric units.';
export const labelDisplayType = 'Display type';
export const labelText = 'Text';
export const labelGauge = 'Gauge';
export const labelBar = 'Bar chart';
export const labelDefaultValueIsDefinedByFirstMetricUsed =
  'The default value is the value defined for the first metric used.';
export const labelNone = 'none';
export const labelValueFormat = 'Value format';
export const labelRawValue = 'Raw value';
export const labelHumanReadable = 'Human readable';
export const labelYouCanChooseOnResourcePerResourceType =
  'You can choose only one resource for each resource type.';
export const labelViewProperties = 'View properties';
export const labelYourRightsOnlyAllowToView =
  'Your rights only allow you to view the properties of a widget.';
export const labelPleaseContactYourAdministrator =
  'Please contact your administrator for more information.';
export const labelLastHour = 'Last hour';
export const labelLast3Hours = 'Last 3 hours';
export const labelLast6Hours = 'Last 6 hours';
export const labelLast12Hours = 'Last 12 hours';
export const labelLast24Hours = 'Last 24 hours';
export const labelLast7Days = 'Last 7 days';
export const labelLast30Days = 'Last 30 days';
export const labelLast3Months = 'Last 3 months';
export const labelLast6Months = 'Last 6 months';
export const labelLast12Months = 'Last 12 months';
export const labelTimePeriod = 'Time period';
export const labelCustomize = 'Customize';
export const labelTo = 'to';
export const labelFrom = 'From';
export const labelStart = 'Start';
export const labelEnd = 'End';
export const labelBaseColor = 'Base color';
export const labelRefresh = 'Refresh';
export const labelDuplicate = 'Duplicate';
export const labelGlobalRefreshInterval = 'Global refresh interval';
export const labelManualRefreshOnly = 'Manual refresh only';
export const labelManual = 'manual';
export const labelShowValueLabels = 'Show value labels';
export const labelDisplay = 'Display';
export const labelHosts = 'hosts';
export const labelTop = 'Top';
export const labelBottom = 'Bottom';
export const labelIncludesXHost = 'Includes {{count}} resources';
export const labelNumberOfValues = 'Number of values';
export const labelViewWidgetProperties = 'View widget properties';
export const labelUnsavedChanges =
  'If you leave without saving your dashboard, changes will be permanently lost.';
export const labelIsTheSelectedResource =
  'is the selected metric by default. Refine filters to select another specific resource.';
export const labelSeeMore = 'See more on the Resources Status page';
export const labelDiscard = 'Discard';
export const labelDoYouWantToSaveChanges = 'Do you want to save the changes?';
export const labelIfYouClickOnDiscard =
  'If you click on Discard, your changes will not be saved.';

==> centreon-web-24.11.0.tar.gz: centreon-web-24.11.0/www/front_src/src/Dashboards/SingleInstancePage/Dashboard/translatedLabels.ts <==
export const labelSave = 'Save';
export const labelEditDashboard = 'Edit dashboard';
export const labelAddWidget = 'Add widget';
export const labelEditWidget = 'Edit widget';
export const labelAddAWidget = 'Add a widget';
export const labelCancel = 'Cancel';
export const labelExitDashboard = 'Exit {{dashboardName}}';
export const labelExitEditionMode = 'Exit edition mode';
export const labelLeaveEditionModeChangesNotSaved =
  'If you leave the edition mode, your changes will not be saved.';
export const labelQuitDashboardChangesNotSaved =
  'If you leave {{dashboardName}}, your changes will not be saved.';
export const labelYourDashboardHasBeenSaved = 'Your dashboard has been saved';
export const labelSelectAWidgetType = 'Select a widget type';
export const labelSearch = 'Search';
export const labelNoWidgetFound = 'No widget found';
export const labelDeleteAWidget = 'Delete widget';
export const labelWidgetType = 'Widget type';
export const labelPleaseChooseAWidgetToActivatePreview =
  'Select a widget type to activate the preview.';
export const labelDeleteWidget = 'Delete widget';
export const labelTheWidgetWillBeDeletedWithName =
  'The {{name}} widget will be permanently deleted.';
export const labelTheWidgetWillBeDeleted =
  'The widget will be permanently deleted.';
export const labelTitle = 'Title';
export const labelDescription = 'Description';
export const labelWidgetProperties = 'Widget properties';
export const labelCommonProperties = 'Common properties';
export const labelRequired = 'Required';
export const labelMoreActions = 'More actions';
export const labelDatasetSelection = 'Dataset selection';
export const labelResources = 'Resources';
export const labelHostGroup = 'Host Group';
export const labelHostCategory = 'Host Category';
export const labelServiceGroup = 'Service Group';
export const labelServiceCategory = 'Service Category';
export const labelHost = 'Host';
export const labelService = 'Service';
export const labelMetaService = 'Meta service';
export const labelDelete = 'Delete';
export const labelResourceType = 'Resource type';
export const labelSelectAResource = 'Select resource';
export const labelSelectResourceType = 'Select type';
export const labelMetrics = 'Metrics';
export const labelPleaseSelectAResource = 'Please select a resource';
export const labelYouHaveTooManyMetrics =
  'You have too many metrics, please filter more resources to optimize platform performance.';
export const labelServiceName = 'Service name';
export const labelMetric = 'Metric';
export const labelSelectMetric = 'Select metric';
export const labelPleaseSelectAMetric = 'Please select a metric';
export const labelShowDescription = 'Show description';
export const labelAddFilter = 'Add filter';
export const labelAddMetric = 'Add metric';
export const labelAvailable = 'available';
export const labelYourWidgetHasBeenModified =
  'Your widget has been modified successfully!';
export const labelYourWidgetHasBeenCreated =
  'Your widget has been created successfully!';
export const labelValueSettings = 'Value settings';
export const labelRefreshInterval = 'Refresh interval';
export const labelDashboardGlobalInterval = 'Dashboard global interval';
export const labelCustomRefreshInterval = 'Custom refresh interval';
export const labelSecond = 'second';
export const labelManualRefresh = 'Manual refresh';
export const labelInterval = 'Interval';
export const labelThresholds = 'Thresholds';
export const labelShowThresholds = 'Show thresholds';
export const labelWarningThreshold = 'Warning threshold';
export const labelCriticalThreshold = 'Critical threshold';
export const labelDefault = 'Default';
export const labelCustom = 'Custom';
export const labelThresholdsAreAutomaticallyHidden =
  'Thresholds are automatically hidden when you select several metrics with different units.';
export const labelDisplayAs = 'Display as';
export const labelText = 'Text';
export const labelGauge = 'Gauge';
export const labelBar = 'Bar chart';
export const labelDefaultValueIsDefinedByFirstMetricUsed =
  'The default value is the value defined for the first selected metric.';
export const labelNone = 'none';
export const labelValueFormat = 'Value format';
export const labelRawValue = 'Raw value';
export const labelHumanReadable = 'Human readable';
export const labelYouCanChooseOnResourcePerResourceType =
  'You can choose only one resource for each resource type.';
export const labelViewProperties = 'View properties';
export const labelYourRightsOnlyAllowToView =
  'Your rights only allow you to view the properties of a widget.';
export const labelPleaseContactYourAdministrator =
  'Please contact your administrator for more information.';
export const labelLastHour = 'Last hour';
export const labelLast3Hours = 'Last 3 hours';
export const labelLast6Hours = 'Last 6 hours';
export const labelLast12Hours = 'Last 12 hours';
export const labelLast24Hours = 'Last 24 hours';
export const labelLast7Days = 'Last 7 days';
export const labelLast30Days = 'Last 30 days';
export const labelLast3Months = 'Last 3 months';
export const labelLast6Months = 'Last 6 months';
export const labelLast12Months = 'Last 12 months';
export const labelTimePeriod = 'Time period';
export const labelCustomize = 'Customize';
export const labelTo = 'to';
export const labelFrom = 'From';
export const labelStart = 'Start';
export const labelEnd = 'End';
export const labelBaseColor = 'Base color';
export const labelRefresh = 'Refresh';
export const labelDuplicate = 'Duplicate';
export const labelGlobalRefreshInterval = 'Global refresh interval';
export const labelManualRefreshOnly = 'Manual refresh only';
export const labelManual = 'manual';
export const labelShowValueLabels = 'Show value labels';
export const labelDisplay = 'Display';
export const labelHosts = 'hosts';
export const labelTop = 'Top';
export const labelBottom = 'Bottom';
export const labelIncludesXHost = 'Includes {{count}} resources';
export const labelNumberOfValues = 'Number of values';
export const labelViewWidgetProperties = 'View widget properties';
export const labelUnsavedChanges =
  'If you leave without saving your dashboard, changes will be permanently lost.';
export const labelIsTheSelectedResource =
  'is the selected metric by default. Refine filters to select another specific resource.';
export const labelSeeMore = 'See more on the {{ page }} page';
export const labelResourcesStatus = 'Resources Status';
export const labelBusinessActivity = 'Business Activity';
export const labelDiscard = 'Discard';
export const labelDoYouWantToSaveChanges = 'Do you want to save the changes?';
export const labelIfYouClickOnDiscard =
  'If you click on Discard, your changes will not be saved.';
export const labelSelectTimezone = 'Select time zone';
export const labelSelectTimeFormat = 'Select time format';
export const labelBackgroundColor = 'Background color';
export const label12Hours = '12 hours';
export const label24Hours = '24 hours';
